@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.012-6-g82e45e2
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.013-3-ge99314f
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -156,6 +156,8 @@ sub _releaser
         $self->log('could not extract user.name and user.email configs from git');
         return;
     }
+    utf8::decode($username);
+    utf8::decode($email);
     $username . ' <' . $email . '>';
 }
 
@@ -201,7 +203,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
